@@ -1,4 +1,4 @@
-/* $Id: VBoxPci-linux.c 100877 2015-06-09 14:23:56Z bird $ */
+/* $Id: VBoxPci-linux.c 102451 2015-09-02 09:47:25Z fmehnert $ */
 /** @file
  * VBoxPci - PCI Driver (Host), Linux Specific Code.
  */
@@ -15,9 +15,10 @@
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
  */
 
-/*******************************************************************************
- *   Header Files                                                               *
- *******************************************************************************/
+
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include "the-linux-kernel.h"
 #include "version-generated.h"
 #include "product-generated.h"
@@ -52,15 +53,16 @@
 #endif /* VBOX_WITH_IOMMU */
 
 
-/*******************************************************************************
- *   Internal Functions                                                         *
- *******************************************************************************/
+/*********************************************************************************************************************************
+*   Internal Functions                                                                                                           *
+*********************************************************************************************************************************/
 static int  VBoxPciLinuxInit(void);
 static void VBoxPciLinuxUnload(void);
 
-/*******************************************************************************
- *   Global Variables                                                           *
- *******************************************************************************/
+
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 static VBOXRAWPCIGLOBALS g_VBoxPciGlobals;
 
 module_init(VBoxPciLinuxInit);
@@ -147,7 +149,9 @@ static int __init VBoxPciLinuxInit(void)
     {
 # if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 30)
         /* find_module() is static before Linux 2.6.30 */
+        mutex_lock(&module_mutex);
         g_VBoxPciGlobals.pciStubModule = find_module(PCI_STUB_MODULE_NAME);
+        mutex_unlock(&module_mutex);
         if (g_VBoxPciGlobals.pciStubModule)
         {
             if (try_module_get(g_VBoxPciGlobals.pciStubModule))
